/* This file is part of KNemo
   Copyright (C) 2004 Percy Leonhardt <percy@eris23.de>

   KNemo is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of
   the License, or (at your option) any later version.

   KNemo is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef CONFIGDIALOG_H
#define CONFIGDIALOG_H

#include <qdict.h>
#include <qpair.h>
#include <qstring.h>

#include <kcmodule.h>

#include "data.h"

class QTimer;
class ConfigDlg;

/**
 * This is the configuration dialog for KNemo
 * It is implemented as a control center module so that it is still
 * possible to configure KNemo even when there is no icon visible
 * in the system tray.
 *
 * @short Configuration dialog for KNemo
 * @author Percy Leonhardt <percy@eris23.de>
 * @version 0.1
 */

class ConfigDialog : public KCModule
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    ConfigDialog( QWidget *parent, const char *name, const QStringList& );

    /**
     * Default Destructor
     */
    virtual ~ConfigDialog();

    void load();
    void save();
    void defaults();

private slots:
    void buttonNewSelected();
    void buttonDeleteSelected();
    void buttonAddToolTipSelected();
    void buttonRemoveToolTipSelected();
    void buttonNotificationsSelected();
    void interfaceSelected( const QString& interface );
    void aliasChanged( const QString& text );
    void startMenuTextChanged( const QString& text );
    void startCommandChanged( const QString& text );
    void stopMenuTextChanged( const QString& text );
    void stopCommandChanged( const QString& text );
    void checkBoxNotConnectedToggled( bool on );
    void checkBoxNotExistingToggled( bool on );
    void checkBoxCustomToggled( bool on );
    void checkBoxStartRootToggled( bool on );
    void checkBoxStopRootToggled( bool on );

private:
    void setupToolTipTab();
    void setupToolTipArray();

    int mToolTipContent;
    ConfigDlg* mDlg;
    QDict<InterfaceSettings> mSettingsDict;
    QPair<QString, int> mToolTips[19];
};

#endif // CONFIGDIALOG_H
